pm4py.statistics.end\_activities.log package
============================================

Submodules
----------

pm4py.statistics.end\_activities.log.get module
-----------------------------------------------

.. automodule:: pm4py.statistics.end_activities.log.get
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.statistics.end_activities.log
   :members:
   :undoc-members:
   :show-inheritance:
